Sale Discount Module
####################

The sale_discount module adds discount on sale line.

Two discount fields are added to the sale line to define a discount as rate and
as amount between a base price and the unit price.
The base price is filled automatically with the list price of the product.
